# termed - TERMinal EDitor

This module is an attempt to create an extensible terminal based editor
that has all the comforts of a typical GUI editor.

It is a rewrite of the module `yated`, which is a simpler
less ambitious editor, which main flaw is lack of support for tabs


